pub enum ProfilingConfig {
None,
Guest {
path: PathBuf,
sample_period: Duration,
},
Native(ProfilingStrategy),
}Expand description
Configuration for profiling Wasm execution.
Viceroy supports two types of profiling:
- Guest profiling: Profiles the WebAssembly guest code itself, producing Firefox profiler compatible JSON.
- Native profiling: Profiles wasmtime’s JIT compiler for debugging across guest, viceroy and wasmtime.
Variants
None
No profiling enabled
Guest
Profile the WebAssembly guest code
Fields
Native(ProfilingStrategy)
Profile wasmtime’s JIT compiler using native profiling tools
Implementations
Sourceimpl ProfilingConfig
impl ProfilingConfig
Sourcepub fn native_strategy(&self) -> ProfilingStrategy
pub fn native_strategy(&self) -> ProfilingStrategy
Get the native profiling strategy for wasmtime