Enum viceroy_lib::error::Error [−][src]
pub enum Error {
Show 26 variants
BufferLengthError {
buf: &'static str,
len: &'static str,
},
FatalError(String),
FileFormat,
FastlyConfig(FastlyConfigError),
BackendUrl(Url),
GuestError(GuestError),
HandleError(HandleError),
HyperError(Error),
Infallible(Infallible),
InvalidArgument,
InvalidHeaderName(InvalidHeaderName),
InvalidHeaderValue(InvalidHeaderValue),
InvalidMethod(InvalidMethod),
InvalidStatusCode(InvalidStatusCode),
InvalidUri(InvalidUri),
IoError(Error),
Other(Error),
Unsupported {
msg: &'static str,
},
DownstreamRespSending,
StreamingChunkSend,
UnknownBackend(String),
DictionaryError(DictionaryError),
Utf8Expected(Utf8Error),
AbiVersionMismatch,
DownstreamRequestError(DownstreamRequestError),
NotAvailable(&'static str),
}Variants
Thrown by hostcalls when a buffer is larger than its *_len limit.
FatalError(String)Error when viceroy has encountered a fatal error and the underlying wasmtime instance must be terminated with a Trap.
Tuple Fields of FatalError
0: StringError when viceroy has been given an invalid file.
FastlyConfig(FastlyConfigError)Tuple Fields of FastlyConfig
BackendUrl(Url)Tuple Fields of BackendUrl
0: UrlGuestError(GuestError)An error from guest-provided arguments to a hostcall. These errors may be created
automatically by the Wiggle-generated glue code that converts parameters from their ABI
representation into richer Rust types, or by fallible methods of GuestPtr in the
wiggle_abi trait implementations.
Tuple Fields of GuestError
0: GuestErrorHandleError(HandleError)Tuple Fields of HandleError
0: HandleErrorHyperError(Error)Tuple Fields of HyperError
0: ErrorInfallible(Infallible)Tuple Fields of Infallible
0: InfallibleError when an invalid argument is supplied to a hostcall.
InvalidHeaderName(InvalidHeaderName)Tuple Fields of InvalidHeaderName
InvalidHeaderValue(InvalidHeaderValue)Tuple Fields of InvalidHeaderValue
InvalidMethod(InvalidMethod)Tuple Fields of InvalidMethod
InvalidStatusCode(InvalidStatusCode)Tuple Fields of InvalidStatusCode
InvalidUri(InvalidUri)Tuple Fields of InvalidUri
0: InvalidUriIoError(Error)Tuple Fields of IoError
0: ErrorOther(Error)Tuple Fields of Other
0: ErrorFields of Unsupported
msg: &'static strDownstream response is already sending.
UnknownBackend(String)Tuple Fields of UnknownBackend
0: StringUtf8Expected(Utf8Error)Tuple Fields of Utf8Expected
0: Utf8ErrorDownstreamRequestError(DownstreamRequestError)Tuple Fields of DownstreamRequestError
NotAvailable(&'static str)Tuple Fields of NotAvailable
0: &'static strImplementations
Convert to an error code representation suitable for passing across the ABI boundary.
For more information about specific error codes see fastly_shared::FastlyStatus,
as well as the witx interface definition located in wasm_abi/typenames.witx.